==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/RootCauseWODetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIONCODEID;
import net.datastream.schemas.mp_fields.CAUSECODEID;
import net.datastream.schemas.mp_fields.FAILURECODEID;
import net.datastream.schemas.mp_fields.PROBLEMCODEID;
import net.datastream.schemas.mp_fields.SYMPTOMID;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID255_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROBLEMCODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FAILURECODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CAUSECODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACTIONCODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FAILUREMODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SYMPTOMID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TACTICALCAUSEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HUMANFACTORID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WORKMANSHIPID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HUMANOVERSIGHTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}METHODOFDETECTIONID" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "problemcodeid",
    "failurecodeid",
    "causecodeid",
    "actioncodeid",
    "failuremodeid",
    "symptomid",
    "tacticalcauseid",
    "humanfactorid",
    "workmanshipid",
    "humanoversightid",
    "methodofdetectionid"
})
@XmlRootElement(name = "RootCauseWODetails")
public class RootCauseWODetails {

    @XmlElement(name = "PROBLEMCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROBLEMCODEID problemcodeid;
    @XmlElement(name = "FAILURECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FAILURECODEID failurecodeid;
    @XmlElement(name = "CAUSECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CAUSECODEID causecodeid;
    @XmlElement(name = "ACTIONCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIONCODEID actioncodeid;
    @XmlElement(name = "FAILUREMODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID255_Type failuremodeid;
    @XmlElement(name = "SYMPTOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYMPTOMID symptomid;
    @XmlElement(name = "TACTICALCAUSEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type tacticalcauseid;
    @XmlElement(name = "HUMANFACTORID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type humanfactorid;
    @XmlElement(name = "WORKMANSHIPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type workmanshipid;
    @XmlElement(name = "HUMANOVERSIGHTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type humanoversightid;
    @XmlElement(name = "METHODOFDETECTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type methodofdetectionid;

    /**
     * Gets the value of the problemcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public PROBLEMCODEID getPROBLEMCODEID() {
        return problemcodeid;
    }

    /**
     * Sets the value of the problemcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public void setPROBLEMCODEID(PROBLEMCODEID value) {
        this.problemcodeid = value;
    }

    /**
     * Gets the value of the failurecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link FAILURECODEID }
     *     
     */
    public FAILURECODEID getFAILURECODEID() {
        return failurecodeid;
    }

    /**
     * Sets the value of the failurecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FAILURECODEID }
     *     
     */
    public void setFAILURECODEID(FAILURECODEID value) {
        this.failurecodeid = value;
    }

    /**
     * Gets the value of the causecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link CAUSECODEID }
     *     
     */
    public CAUSECODEID getCAUSECODEID() {
        return causecodeid;
    }

    /**
     * Sets the value of the causecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAUSECODEID }
     *     
     */
    public void setCAUSECODEID(CAUSECODEID value) {
        this.causecodeid = value;
    }

    /**
     * Gets the value of the actioncodeid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIONCODEID }
     *     
     */
    public ACTIONCODEID getACTIONCODEID() {
        return actioncodeid;
    }

    /**
     * Sets the value of the actioncodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIONCODEID }
     *     
     */
    public void setACTIONCODEID(ACTIONCODEID value) {
        this.actioncodeid = value;
    }

    /**
     * Gets the value of the failuremodeid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID255_Type }
     *     
     */
    public USERDEFINEDCODEID255_Type getFAILUREMODEID() {
        return failuremodeid;
    }

    /**
     * Sets the value of the failuremodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID255_Type }
     *     
     */
    public void setFAILUREMODEID(USERDEFINEDCODEID255_Type value) {
        this.failuremodeid = value;
    }

    /**
     * Gets the value of the symptomid property.
     * 
     * @return
     *     possible object is
     *     {@link SYMPTOMID }
     *     
     */
    public SYMPTOMID getSYMPTOMID() {
        return symptomid;
    }

    /**
     * Sets the value of the symptomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYMPTOMID }
     *     
     */
    public void setSYMPTOMID(SYMPTOMID value) {
        this.symptomid = value;
    }

    /**
     * Gets the value of the tacticalcauseid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTACTICALCAUSEID() {
        return tacticalcauseid;
    }

    /**
     * Sets the value of the tacticalcauseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTACTICALCAUSEID(USERDEFINEDCODEID_Type value) {
        this.tacticalcauseid = value;
    }

    /**
     * Gets the value of the humanfactorid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getHUMANFACTORID() {
        return humanfactorid;
    }

    /**
     * Sets the value of the humanfactorid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setHUMANFACTORID(USERDEFINEDCODEID_Type value) {
        this.humanfactorid = value;
    }

    /**
     * Gets the value of the workmanshipid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getWORKMANSHIPID() {
        return workmanshipid;
    }

    /**
     * Sets the value of the workmanshipid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setWORKMANSHIPID(USERDEFINEDCODEID_Type value) {
        this.workmanshipid = value;
    }

    /**
     * Gets the value of the humanoversightid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getHUMANOVERSIGHTID() {
        return humanoversightid;
    }

    /**
     * Sets the value of the humanoversightid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setHUMANOVERSIGHTID(USERDEFINEDCODEID_Type value) {
        this.humanoversightid = value;
    }

    /**
     * Gets the value of the methodofdetectionid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMETHODOFDETECTIONID() {
        return methodofdetectionid;
    }

    /**
     * Sets the value of the methodofdetectionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMETHODOFDETECTIONID(USERDEFINEDCODEID_Type value) {
        this.methodofdetectionid = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/RootCauseWODetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIONCODEID;
import net.datastream.schemas.mp_fields.CAUSECODEID;
import net.datastream.schemas.mp_fields.FAILURECODEID;
import net.datastream.schemas.mp_fields.PROBLEMCODEID;
import net.datastream.schemas.mp_fields.SYMPTOMID;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID255_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROBLEMCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILURECODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAUSECODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIONCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILUREMODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYMPTOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TACTICALCAUSEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HUMANFACTORID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKMANSHIPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HUMANOVERSIGHTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}METHODOFDETECTIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "problemcodeid",
    "failurecodeid",
    "causecodeid",
    "actioncodeid",
    "failuremodeid",
    "symptomid",
    "tacticalcauseid",
    "humanfactorid",
    "workmanshipid",
    "humanoversightid",
    "methodofdetectionid"
})
@XmlRootElement(name = "RootCauseWODetails")
public class RootCauseWODetails {

    @XmlElement(name = "PROBLEMCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROBLEMCODEID problemcodeid;
    @XmlElement(name = "FAILURECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FAILURECODEID failurecodeid;
    @XmlElement(name = "CAUSECODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CAUSECODEID causecodeid;
    @XmlElement(name = "ACTIONCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIONCODEID actioncodeid;
    @XmlElement(name = "FAILUREMODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID255_Type failuremodeid;
    @XmlElement(name = "SYMPTOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYMPTOMID symptomid;
    @XmlElement(name = "TACTICALCAUSEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type tacticalcauseid;
    @XmlElement(name = "HUMANFACTORID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type humanfactorid;
    @XmlElement(name = "WORKMANSHIPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type workmanshipid;
    @XmlElement(name = "HUMANOVERSIGHTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type humanoversightid;
    @XmlElement(name = "METHODOFDETECTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type methodofdetectionid;

    /**
     * Gets the value of the problemcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public PROBLEMCODEID getPROBLEMCODEID() {
        return problemcodeid;
    }

    /**
     * Sets the value of the problemcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROBLEMCODEID }
     *     
     */
    public void setPROBLEMCODEID(PROBLEMCODEID value) {
        this.problemcodeid = value;
    }

    /**
     * Gets the value of the failurecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link FAILURECODEID }
     *     
     */
    public FAILURECODEID getFAILURECODEID() {
        return failurecodeid;
    }

    /**
     * Sets the value of the failurecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FAILURECODEID }
     *     
     */
    public void setFAILURECODEID(FAILURECODEID value) {
        this.failurecodeid = value;
    }

    /**
     * Gets the value of the causecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link CAUSECODEID }
     *     
     */
    public CAUSECODEID getCAUSECODEID() {
        return causecodeid;
    }

    /**
     * Sets the value of the causecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAUSECODEID }
     *     
     */
    public void setCAUSECODEID(CAUSECODEID value) {
        this.causecodeid = value;
    }

    /**
     * Gets the value of the actioncodeid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIONCODEID }
     *     
     */
    public ACTIONCODEID getACTIONCODEID() {
        return actioncodeid;
    }

    /**
     * Sets the value of the actioncodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIONCODEID }
     *     
     */
    public void setACTIONCODEID(ACTIONCODEID value) {
        this.actioncodeid = value;
    }

    /**
     * Gets the value of the failuremodeid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID255_Type }
     *     
     */
    public USERDEFINEDCODEID255_Type getFAILUREMODEID() {
        return failuremodeid;
    }

    /**
     * Sets the value of the failuremodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID255_Type }
     *     
     */
    public void setFAILUREMODEID(USERDEFINEDCODEID255_Type value) {
        this.failuremodeid = value;
    }

    /**
     * Gets the value of the symptomid property.
     * 
     * @return
     *     possible object is
     *     {@link SYMPTOMID }
     *     
     */
    public SYMPTOMID getSYMPTOMID() {
        return symptomid;
    }

    /**
     * Sets the value of the symptomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYMPTOMID }
     *     
     */
    public void setSYMPTOMID(SYMPTOMID value) {
        this.symptomid = value;
    }

    /**
     * Gets the value of the tacticalcauseid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTACTICALCAUSEID() {
        return tacticalcauseid;
    }

    /**
     * Sets the value of the tacticalcauseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTACTICALCAUSEID(USERDEFINEDCODEID_Type value) {
        this.tacticalcauseid = value;
    }

    /**
     * Gets the value of the humanfactorid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getHUMANFACTORID() {
        return humanfactorid;
    }

    /**
     * Sets the value of the humanfactorid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setHUMANFACTORID(USERDEFINEDCODEID_Type value) {
        this.humanfactorid = value;
    }

    /**
     * Gets the value of the workmanshipid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getWORKMANSHIPID() {
        return workmanshipid;
    }

    /**
     * Sets the value of the workmanshipid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setWORKMANSHIPID(USERDEFINEDCODEID_Type value) {
        this.workmanshipid = value;
    }

    /**
     * Gets the value of the humanoversightid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getHUMANOVERSIGHTID() {
        return humanoversightid;
    }

    /**
     * Sets the value of the humanoversightid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setHUMANOVERSIGHTID(USERDEFINEDCODEID_Type value) {
        this.humanoversightid = value;
    }

    /**
     * Gets the value of the methodofdetectionid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMETHODOFDETECTIONID() {
        return methodofdetectionid;
    }

    /**
     * Sets the value of the methodofdetectionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMETHODOFDETECTIONID(USERDEFINEDCODEID_Type value) {
        this.methodofdetectionid = value;
    }

}
